# g2nb

**g2nb** combines the accessibility and research narrative capabilities of [Jupyter](https://jupyter.org) with 
the genomics tools available in [Galaxy](https://usegalaxy.org), [GenePattern](https://genepattern.org), and 
other popular bioinformatics platforms, adding many features for ease of use by non-programming scientists.

## Installation

Installing this meta-package gets you the entire suite of g2nb tools.

> pip install g2nb

## Features

* **[GenePattern Notebook](https://github.com/genepattern/genepattern-notebook):** gives GenePattern users the 
     ability to interleave text, graphics, and code with their GenePattern analyses to create "notebooks" that 
     can be edited, shared, and published.
* **[GalaxyLab](https://github.com/jaidevjoshi83/galaxylab):** Support for Galaxy analyses in Jupyter notebooks.
* **[igv-jupyter](https://github.com/g2nb/igv-jupyter):** An extension for Jupyter which wraps igv.js, the 
      javascript version of the Integrative Genomics Viewer.
* **[jupyter-wysiwyg](https://github.com/g2nb/jupyter-wysiwyg):** A rich test editor for markdown cells.
* **[nbtools](https://github.com/g2nb/nbtool-manager):** A framework for creating user-friendly Jupyter 
      notebooks that are accessible to both programming and non-programming users.